Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Action ¶
type Action struct {
Created time.Time `json:"created"`
Modified time.Time `json:"modified"`
OrganizationID string `json:"organizationId"`
DeviceID string `json:"deviceId"`
ActionID string `json:"actionId"`
Action string `json:"action"`
Status string `json:"status"`
Message string `json:"message"`
}
Action is the log of an action request
type ActionResponseBytes ¶
type ActionResponseBytes struct {
ID string `json:"id"`
Action string `json:"action"`
Success bool `json:"success"`
Message string `json:"message"`
Result []byte `json:"result"`
}
ActionResponseBytes is the published message showing the result of an action, with the result as bytes
type Device ¶
type Device struct {
OrganizationID string `json:"orgId"`
DeviceID string `json:"deviceId"`
Brand string `json:"brand"`
Model string `json:"model"`
SerialNumber string `json:"serial"`
StoreID string `json:"store"`
DeviceKey string `json:"deviceKey"`
Version DeviceVersion `json:"version"`
Created time.Time `json:"created"`
LastRefresh time.Time `json:"lastRefresh"`
}
Device holds the details of a device
type DeviceSnap ¶
type DeviceSnap struct {
DeviceID string `json:"deviceId"`
Name string `json:"name"`
InstalledSize int64 `json:"installedSize"`
InstalledDate time.Time `json:"installedDate"`
Status string `json:"status"`
Channel string `json:"channel"`
Confinement string `json:"confinement"`
Version string `json:"version"`
Revision int `json:"revision"`
Devmode bool `json:"devmode"`
Config string `json:"config"`
}
DeviceSnap holds the details of snap on a device
type DeviceVersion ¶
type DeviceVersion struct {
DeviceID string `json:"deviceId"`
Version string `json:"version"`
Series string `json:"series"`
OSID string `json:"osId"`
OSVersionID string `json:"osVersionId"`
OnClassic bool `json:"onClassic"`
KernelVersion string `json:"kernelVersion"`
}
DeviceVersion holds the details of the OS on a device
type Health ¶
type Health struct {
OrganizationID string `json:"orgId"`
DeviceID string `json:"deviceId"`
Refresh time.Time `json:"refresh"`
}
Health update contains enough details to record a device
type PublishDevice ¶
type PublishDevice struct {
ID string `json:"id"`
Action string `json:"action"`
Success bool `json:"success"`
Message string `json:"message"`
Result Device `json:"result"`
}
PublishDevice is the published message showing the result of a device action
type PublishDeviceVersion ¶
type PublishDeviceVersion struct {
ID string `json:"id"`
Action string `json:"action"`
Success bool `json:"success"`
Message string `json:"message"`
Result DeviceVersion `json:"result"`
}
PublishDeviceVersion is the published message showing the result of a server action
type PublishResponse ¶
type PublishResponse struct {
ID string `json:"id"`
Action string `json:"action"`
Success bool `json:"success"`
Message string `json:"message"`
Result interface{} `json:"result"`
}
PublishResponse is the published message showing the result of an action
type PublishSnap ¶
type PublishSnap struct {
ID string `json:"id"`
Action string `json:"action"`
Success bool `json:"success"`
Message string `json:"message"`
Result DeviceSnap `json:"result"`
}
PublishSnap is the published message showing the result of a conf snap action
type PublishSnapTask ¶
type PublishSnapTask struct {
ID string `json:"id"`
Action string `json:"action"`
Success bool `json:"success"`
Message string `json:"message"`
Result string `json:"result"`
}
PublishSnapTask is the published message showing the result of a snap action
type PublishSnaps ¶
type PublishSnaps struct {
ID string `json:"id"`
Action string `json:"action"`
Success bool `json:"success"`
Message string `json:"message"`
Result []DeviceSnap `json:"result"`
}
PublishSnaps is the published message showing the result of a list snaps action